@@ -1,9 +1,8 @@
 #!/usr/bin/env perl
 
-# PERL_FUTURE_DEBUG=1 perl eg/math.pl
+# PERL_FUTURE_DEBUG=1 perl eg/control-change.pl
 
 use curry;
-use Future::IO::Impl::IOAsync;
 use MIDI::RtController ();
 use MIDI::RtController::Filter::CC ();
 
