@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0104';
 
 use v5.36;
 
@@ -117,7 +117,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0102
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -132,8 +132,8 @@ version 0.0102
 
   my $filter = MIDI::RtController::Filter::CC->new(rtc => $control);
 
-  $filter->channel(1);
-  $filter->control(77);
+  $filter->control(1); # CC#01 = mod-wheel
+  $filter->channel(0);
   $filter->range_bottom(10);
   $filter->range_top(100);
   $filter->range_step(2);
@@ -148,6 +148,21 @@ version 0.0102
 C<MIDI::RtController::Filter::CC> is a (growing) collection of
 control-change based L<MIDI::RtController> filters.
 
+=head2 Making filters
+
+All filter methods must accept the object, a MIDI device name, a
+delta-time, and a MIDI event ARRAY reference, like:
+
+  sub breathe ($self, $device, $delta, $event) {
+    my ($event_type, $chan, $control, $value) = $event->@*;
+    ...
+    return $boolean;
+  }
+
+A filter also must return a boolean value. This tells
+L<MIDI::RtController> to continue processing other known filters or
+not.
+
 =head1 ATTRIBUTES
 
 =head2 rtc
@@ -171,9 +186,9 @@ Default: C<0>
   $control = $filter->control;
   $filter->control($number);
 
-The current MIDI control-change number ("CC#") between C<0> and C<127>.
+Return or set the control change number between C<0> and C<127>.
 
-Default: C<1> (synthesizer mod-wheel)
+Default: C<1> (mod-wheel)
 
 =head2 range_bottom
 
@@ -233,26 +248,24 @@ Default: C<0>
 
 =head1 METHODS
 
-All filter methods must accept the object, a MIDI device name, a
-delta-time, and a MIDI event ARRAY reference, like:
+=head2 new
 
-  sub breathe ($self, $device, $delta, $event) {
-    my ($event_type, $chan, $note, $value) = $event->@*;
-    ...
-    return $boolean;
-  }
+  $filter = MIDI::RtController::Filter::CC->new(%arguments);
 
-A filter also must return a boolean value. This tells
-L<MIDI::RtController> to continue processing other known filters or
-not.
+Return a new C<MIDI::RtController::Filter::CC> object.
 
 =head2 breathe
 
+  $control->add_filter('breathe', all => $filter->curry::breathe);
+
 This filter sets the B<running> flag and then iterates between the
 B<range_bottom> and B<range_top> by B<range_step> increments, sending
 a B<control> change message, over the MIDI B<channel> every iteration,
 until B<stop> is seen.
 
+Passing C<all> means that any MIDI event will cause this filter to be
+triggered.
+
 =head1 SEE ALSO
 
 L<Iterator::Breathe>
